@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2016 Iñaki Ucar
+# Copyright (C) 2015-2023 Iñaki Ucar
 #
 # This file is part of simmer.
 #
@@ -23,7 +23,7 @@ test_that("a simple deterministic simulation with rejections behaves as expected
     timeout(function() 1.5) %>%
     release("server", 1)
 
-  env <- simmer(verbose = TRUE) %>%
+  env <- simmer(verbose = env_verbose) %>%
     add_resource("server", 1, queue_size = 0) %>%
     add_generator("entity", t0, at(1:n))
 
