@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2018 Iñaki Ucar
+# Copyright (C) 2015-2023 Iñaki Ucar
 #
 # This file is part of simmer.
 #
@@ -28,7 +28,7 @@ test_that("the wrapper behaves as expected", {
     timeout(1) %>%
     rollback(1, times = Inf)
 
-  env <- simmer(verbose = TRUE) %>%
+  env <- simmer(verbose = env_verbose) %>%
     add_resource("server", 1, 0) %>%
     add_generator("dummy", t0, at(1:10), mon = 2) %>%
     add_generator("rollback", t1, at(11)) %>%
